.. :changelog:

Release History
---------------

0.10 (2015-03-03)
++++++++++++++++
- Fix Windows support


0.8 (2015-02-01)
++++++++++++++++
- Rewritten to use MetaKernel - provides a full suite of magics
- %inline magic no longer supported - %plot magic support coming soon
- No longer depends on Oct2Py


0.7 (2014-10-19)
++++++++++++++++
- Update for compatibility with IPython 3.0 message spec changes.


0.6 (2014-09-24)
++++++++++++++++
- Update for compatibility with oct2py 2.4.


0.5 (2014-08-23)
++++++++++++++++
- Add %inline --format and --size options.


0.4 (2014-08-10)
++++++++++++++++
- Add Python 3 support.
- Add %inline plotting toggle.
- Add compatibility for oct2py >= 2.0.


0.3 (2014-08-03)
+++++++++++++++++
- Cache help strings and calltips for fast re-trigger.


0.2 (2014-08-02)
+++++++++++++++++
- Add history capability


0.1 (2014-08-01)
++++++++++++++++++
- Initial release: provides completion and calltips.
